<?php

namespace Drupal\users_export;

use Drupal\Component\Utility\Html;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * User Export Permissions Class.
 */
class UsersExportPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * Returns the users_export.loft_data_grids service.
   *
   * @var \Drupal\users_export\UserExportLoftDataGrids
   */
  private $loftDataGrids;

  /**
   * Constructs a new UsersExportPermissions instance.
   *
   * @param \Drupal\users_export\UserExportLoftDataGrids $loft_data_grids
   *   Manager class to get available exporters.
   */
  public function __construct(UserExportLoftDataGrids $loft_data_grids) {
    $this->loftDataGrids = $loft_data_grids;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('users_export.loft_data_grids'));
  }

  /**
   * Return the permissions defined by this module.
   *
   * @return array
   *   Array of export permssions.
   */
  public function permissions() {
    $perms = [];

    foreach ($this->loftDataGrids->getExporters(FALSE) as $info) {
      $perms['users_export:export as ' . $info['id']] = [
        'title' => $this->t('Export as @name', ['@name' => $info['name']]),
        'description' => Html::escape($info['description']),
      ];
    }

    return $perms;
  }

}
